@@ -119,7 +119,10 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
 
     def _engine_started(self) -> Deferred:
         """Launch the browser. Use the engine_started signal as it supports returning deferreds."""
-        return deferred_from_coro(self._launch_browser())
+        if not self.playwright_user_agents:
+            return deferred_from_coro(self._launch_browser())
+        else:
+            return deferred_from_coro(self._launch_browser(user_agent=self.playwright_user_agents[1]))
 
     def _ip_changed(self) -> Deferred:
         """Plan User-Agent rotation"""
@@ -174,7 +177,7 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
         context = self.contexts.get("default")
 
         page = await context.new_page()
-        await stealth_async(page)
+        await stealth_async(page, logger)
         self.stats.inc_value("playwright/page_count")
         logger.debug(
             "[Context=%s] New page created, page count is %i (%i for all contexts)",
